//@line 37 "/home/ondrejd/mozilla/extensions/xpcomviewer/resources/content/xpcomviewer-commands.js"


var gSupportedCommands = null;



/**
 * XpcomViewer's commands controller
 * 
 * @var nsIController
 */
var gXpcomViewerController =
{
  getCommandStateparams : function(aCmd) {},
  doCommandParams : function(aCmd) {},
  
  /**
   * Returns true if command is supported
   * @param  string   ID of command
   * @return boolean
   */
  supportsCommand : function(aCmd)
  {
    return (aCmd in gSupportedCommands);
  }, // end supportsCommand(aCmd)
  
  
  /**
   * Returns true if command is enabled now
   * @param  string   ID of command
   * @return boolean
   */
  isCommandEnabled : function(aCmd)
  {
    if(this.supportsCommand(aCmd)) {
      return gSupportedCommands[aCmd].isCommandEnabled(aCmd);
    }
    
    Components.utils.reportError("gXpcomViewerController::isCommandEnabled " +
                                 "- Unknown command '" + aCmd + "'!");
    return false;
  }, // end isCommandEnabled(aCmd)
  
  
  /**
   * Execute requested command
   * @param  string   ID of command
   * @return boolean
   */
  doCommand : function(aCmd)
  {
    if(this.supportsCommand(aCmd)) {
      return gSupportedCommands[aCmd].doCommand(aCmd);
    }
    
    Components.utils.reportError("gXpcomViewerController::doCommand " +
                                 "- Unknown command '" + aCmd + "'!");
    return false;
  }, // end doCommand(aCmd)
  
  
  /**
   * Fired when command is executed. (This event is not fired automatically
   * it must be fired by code). We do not use it.
   * @param  nsiEvent
   */
  onEvent : function(aEvent) {}

}; // End of gXpcomViewerController



///////////////////////////////////////////////////////////////////////////////
// Single commands implementation


/**
 * Quit XPCOMViewer command
 */
var gCmdQuit =
{
  isCommandEnabled : function(aCommand) { return true; },
  getCommandStateParams : function(aCommand, aParams, aRefCon) {},
  doCommandParams : function(aCommand, aParams, aRefCon) {},
  doCommand : function(aCommand)
  {
    window.close();
  }
}; // End of gCmdQuit


/**
 * Update XPCOMViewer's user interface
 */
var gCmdUpdateUI =
{
  isCommandEnabled : function(aCommand) { return true; },
  getCommandStateParams : function(aCommand, aParams, aRefCon) {},
  doCommandParams : function(aCommand, aParams, aRefCon) {},
  doCommand : function(aCommand)
  {
    // Update XPCOMViewer title
    if(!gXpcomTreeFilter) {
      document.title = gStrBundle.getFormattedString("xpcomviewerWindowTitle", 
          [kTreeViewsNames[gCurrentTreeView], gXpcomTree.view.rowCount])
    } else {
      document.title = gStrBundle.getFormattedString("xpcomviewerWindowTitle1", 
          [kTreeViewsNames[gCurrentTreeView], gXpcomTree.view.rowCount]);
    }
    
    // Update title of xpcom tree parent tab
    switch(gCurrentTreeView) {
      case "classes":
        gXpcomTreeTab.setAttribute("label", gStrBundle.getString("mainTreeLabelClasses"));
        gXpcomTreeTab.setAttribute("class", "classesView-tab");
        break;
      
      case "ifaces":
        gXpcomTreeTab.setAttribute("label", gStrBundle.getString("mainTreeLabelIfaces"));
        gXpcomTreeTab.setAttribute("class", "ifacesView-tab");
        break;
      
      case "results":
        gXpcomTreeTab.setAttribute("label", gStrBundle.getString("mainTreeLabelResults"));
        gXpcomTreeTab.setAttribute("class", "resultsView-tab");
        break;
    }
    
    // Updates cmd_showLXRSearch related UI elements
    if(!gLxrBrowserTab.collapsed) {
      var current_uri = gMainContent.contentDocument.location.href;
        
      if(current_uri.indexOf("http://mxr.mozilla.org/search") == 0) {
        gLxrBrowserCmdMenuitem.checked = true;
        gLxrBrowserCmdPopupitem.checked = true;
      } else {
        gLxrBrowserCmdMenuitem.checked = false;
        gLxrBrowserCmdPopupitem.checked = false;
      }
    }
    
    // Update bookmarks related UI elements
    if(!gAllowBookmarks) {
      gBookmarksPopupitem1.collapsed = true;
      gBookmarksPopupitem2.collapsed = true;
      gBookmarksPopupSeparator.collapsed = true;
      gBookmarksTogglePaneMenuitem.collapsed = true;
      gBookmarksTogglePaneMenuitemSep.collapsed = true;
      gBookmaksToolbarbutton.collapsed = true;
      gBookmaksToolbarbuttonSeparator.collapsed = true;
      gBookmarksFilterToolbarbutton.collapsed = true;
      gBookmarksFilterToolbarbuttonSep.collapsed = true;
      gBookmarksMainTreeCol.collapsed = true;
      gBookmarksMainTreeColSep.collpased = true;
    } else {
      gBookmarksPopupitem1.collapsed = false;
      gBookmarksPopupitem2.collapsed = false;
      gBookmarksPopupSeparator.collapsed = false;
      gBookmarksTogglePaneMenuitem.collapsed = false;
      gBookmarksTogglePaneMenuitemSep.collapsed = false;
      gBookmaksToolbarbutton.collapsed = false;
      gBookmaksToolbarbuttonSeparator.collapsed = false;
      gBookmarksFilterToolbarbutton.collapsed = false;
      gBookmarksFilterToolbarbuttonSep.collapsed = false;
      gBookmarksMainTreeCol.collapsed = false;
      gBookmarksMainTreeColSep.collpased = false;
    }
    
    // Update statusbar
    gStatusbar.nextMessage();
  }
}; // End of gCmdUpdateUI


/**
 * Toggle full screen view command
 */
var gCmdFullScreen = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    window.fullScreen = !window.fullScreen;
    // XXX kObserverSrv.notifyObservers(kObserverSrv, "fullScreenModeChanged", "");
  }
}; // End of gCmdFullScreen


/**
 * Show about dialog
 */
var gCmdShowAbout = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    showAboutDialog();
  }
}; // End of gCmdShowAbout


/**
 * Show home page
 */
var gCmdShowHomePage = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    showHomePage();
  }
}; // End of gCmdShowHomePage


/**
 * Show help window
 */
var gCmdShowHelp = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    showHelp();
  }
}; // End of gCmdShowHelp


/**
 * Show JavaScript console
 */
var gCmdShowJsConsole = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    toJavaScriptConsole();
  }
}; // End of gCmdShowJsConsole


/**
 * Show preferences dialog
 */
var gCmdShowPreferences = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    showPreferences();
  }
}; // End of gCmdShowPreferences


/**
 * Save report
 * (implements 'cmd_saveAsXML', 'cmd_saveAsHTML', 'cmd_saveAsTXT')
 */
var gCmdSaveReportAs = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var type = new String(aCommand).replace("cmd_saveAs", "").toLowerCase();
    
    // Show filepicker
    var fp = Components.classes["@mozilla.org/filepicker;1"].
        createInstance(Components.interfaces.nsIFilePicker);
    fp.init(window, gStrBundle.getString("saveAsDlgLabel"), 
        Components.interfaces.nsIFilePicker.modeSave);
    
    var res = fp.show();
    var file = null;
    
    if(res == Components.interfaces.nsIFilePicker.returnOK) {
      file = fp.file;
    } else if(res == Components.interfaces.nsIFilePicker.returnReplace) {
      file = fp.file;
    }
    
    // Start document
    var doc = null;
    if(type == "xml")
    {
      doc = Components.classes["@mozilla.org/xml/xml-document;1"].
          createInstance(Components.interfaces.nsIDOMDocument);
      doc = doc.implementation.createDocument("", gCurrentTreeView, null);
    }
    else if(type == "html")
    {
      // XXX Attach stylesheet???
      doc = "<html>\n" +
            "<head>\n" +
            "<title>" + kTreeViewsNames[gCurrentTreeView] + "</title>\n" +
            "</head>\n" +
            "<body>\n" +
            "<h1>" + kTreeViewsNames[gCurrentTreeView] + "</h1>\n" + 
            "<ul>\n";
    }
    else
    {
      doc = kTreeViewsNames[gCurrentTreeView] + "\n\n";
    }
    
    // Fill document
    for(var i=0; i<gXpcomTree.view.rowCount; i++)
    {
      var itemName = gXpcomTree.view.getCellText(i, gXpcomTree.columns.getPrimaryColumn());
      var itemId = gXpcomTree.view.getCellText(i, gXpcomTree.columns.getColumnAt(2));
      
      switch(type)
      { 
        case "xml":
          var itemElm = doc.createElement("item", "");
          itemElm.setAttribute("name", itemName);
          itemElm.setAttribute("id", itemId);
          doc.documentElement.appendChild(itemElm);
          break;
        
        case "html":
          doc = doc + "<li>" + itemName + " - " + itemId + "</li>\n";
          break;
        
        case "txt":
        default:
          doc = doc + kTreeViewsItemNames[gCurrentTreeView] + ": \"" +
              itemName + "\" \"" + itemId + "\"\n";
          break;
      }
    }
    
    // Finish document
    if(type == "xml")
    {
      // XXX Attach stylesheet???
    }
    else if(type == "html")
    {
      doc = doc + "</body>\n</html>";
    }
    
    // Save to file
    var res1 = (type == "xml") ? writeXmlToFile(file, doc)
                               : writeTextToFile(file, doc);
    
    if(!res1) {
      gStatusbar.update(gStrBundle.getString("saveAsFailedMsg"), "error");
    }
  }
}; // End of gCmdSaveAs


/**
 * Show choosen tree view
 * (implements 'cmd_showClasses', 'cmd_showIfaces', 'cmd_showResults')
 */
var gCmdShowView = 
{
  isCommandEnabled: function(aCommand) { return true; },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var view = (new String(aCommand)).replace("cmd_show", "").toLowerCase();
    gXpcomViewer.refreshTree(view);
  }
}; // End of gCmdShowView


/**
 * Apply filter on tree items
 */
var gCmdShowFiltered = 
{
  isCommandEnabled: function(aCommand)
  {
    return (gFilterToolbarTextbox.value !== "");
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
	  var currentTreeView = gXpcomTreeViewBackup[gCurrentTreeView];
	  var newTreeView = [];
    var searchString = gFilterToolbarTextbox.value.toLowerCase();
    
    var item = null;
    for(item in currentTreeView) {
      var name = currentTreeView[item].mColumns["nameCol"].mCellText.toLowerCase();
      
      if (name.indexOf(searchString)!=-1) {
        newTreeView.push (currentTreeView[item]);
      }
    }
    
	  gXpcomTreeFilter = true;
    
    switch(gCurrentTreeView) {
      case "classes":
        gXpcomTree.view = new TreeClassesPrototype(newTreeView);
        break;
      
      case "ifaces":
        gXpcomTree.view = new TreeIfacesPrototype(newTreeView);
        break;
      
      case "results":
        gXpcomTree.view = new TreeResultsPrototype(newTreeView);
        break;
    }
    
    // Update user interface
    gStatusbar.update(gStrBundle.getFormattedString("filterAppliedMsg",
        [newTreeView.length]), "success");
  }
}; // End of gCmdShowFiltered


/**
 * Show all tree items (remove filter)
 */
var gCmdShowAll = 
{
  isCommandEnabled: function(aCommand)
  {
    return gXpcomTreeFilter;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    switch(gCurrentTreeView)
    {
      case "classes":
        gXpcomTree.view = new TreeClassesPrototype(gXpcomTreeViewBackup[gCurrentTreeView]);
        break;
      
      case "ifaces":
        gXpcomTree.view = new TreeIfacesPrototype(gXpcomTreeViewBackup[gCurrentTreeView]);
        break;
      
      case "results":
        gXpcomTree.view = new TreeResultsPrototype(gXpcomTreeViewBackup[gCurrentTreeView]);
        break;
    }
    gXpcomTreeFilter = false;
    
    var textbox = document.getElementById("main-search-textbox");
    if(textbox) textbox.value = "";
  }
}; // End of gCmdShowAll


/**
 * Show selected interface source
 * (implements 'cmd_ifaceLocalLookup', 'cmd_ifaceLXRLookup')
 */
var gCmdLXRLookup = 
{
  isCommandEnabled: function(aCommand) {
    return (gXpcomViewer.getSelectedTreeItem().mIndex == -1 &&
            gCurrentTreeView == "results")
        ? false
        : true;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var selected = gXpcomViewer.getSelectedTreeItem();
    var res = false;
    
    var selected = gXpcomViewer.getSelectedTreeItem();
    var lxrserver_uri = kPrefs.getCharPref("selectedLXRServer");
    var search_uri = "";
    
    switch(selected.mType) {
      case "interface":
        search_uri = lxrserver_uri + "seamonkey/find?string=" + selected.mName;
        break;
        
      case "class":
        search_uri = lxrserver_uri + "seamonkey/search?string=" + selected.mName;
        break;
      
      case "ifaceConstant":
      case "property":
      case "result":
      default:
        gStatusbar.update(gStrBundle.getString("noLXRSearchForGivenType"), "warning");
        return;
        break;
    }
    
    gMainContent.addProgressListener(gWebProgressListener, NOTIFY_STATE_DOCUMENT);
    gMainContent.webNavigation.loadURI(search_uri, 0, null, null, null);
    
    var tabs = document.getElementById("workspace-tabbox-tabs");
    var browser_tab = document.getElementById("lxr_lookup-tab");
    var lxr_deck = document.getElementById("lxr_lookup-deck");
    browser_tab.collapsed = false;
    tabs.collapsed = false;
    lxr_deck.selectedIndex = 0;
    tabs.selectedIndex = 1;
  }
}; // End of gCmdLXRLookup


/**
 * Shows LXR search page on browser's pane
 */
var gCmdShowLXRSearchPage =
{
  isCommandEnabled: function(aCommand) {
    return true;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var tabs = document.getElementById("workspace-tabbox-tabs");
    var browser_tab = document.getElementById("lxr_lookup-tab");
    var mainmenuitem = document.getElementById("showLxrSearchPage-mainmenuitem");
    var popupmenuitem = document.getElementById("showLxrSearchPage-popupmenuitem");
    
    var lxr_deck = document.getElementById("lxr_lookup-deck");
    lxr_deck.selectedIndex = 0;
      
    if(mainmenuitem.checked && popupmenuitem.checked) {
      // Hide LXR search page
      tabs.selectedIndex = 0;
      browser_tab.collapsed = true;
      tabs.collapsed = true;
      gMainContent.webNavigation.loadURI("about:blank", 0, null, null, null);
    } else {
      // Show LXR search page
      browser_tab.collapsed = false;
      tabs.collapsed = false;
      var lxrserver_uri = kPrefs.getCharPref("selectedLXRServer");
      gMainContent.addProgressListener(gWebProgressListener, NOTIFY_STATE_DOCUMENT);
      gMainContent.webNavigation.loadURI(lxrserver_uri + "search", 0, null, null, null);
      tabs.selectedIndex = 1;
    }
  }
}; // End of gCmdShowLXRSearchPage


/**
 * Close tab with LXR
 */
var gCmdCloseLXRTab = 
{
  isCommandEnabled: function(aCommand) {
    return true;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var tabs = document.getElementById("workspace-tabbox-tabs");
    var browser_tab = document.getElementById("lxr_lookup-tab");
    
    tabs.selectedIndex = 0;
    browser_tab.collapsed = true;
    tabs.collapsed = true;
    gMainContent.webNavigation.loadURI("about:blank", 0, null, null, null);
  }
}; // End of gCmdCloseLXRTab


/**
 * Copy name of selected tree item into clipboard
 */
var gCmdCopyNameOfSel = 
{
  isCommandEnabled: function(aCommand) {
    return (gXpcomViewer.getSelectedTreeItem().mIndex == -1) ? false : true;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var selected = gXpcomViewer.getSelectedTreeItem();
    
    var res = copyTextToClipboard(selected.mName);
    if(!res) gStatusbar.update(gStrBundle.getString("doCommandError"), "error");
  }
}; // End of gCmdCopyNameOfSel


/**
 * Generate interface initialization code 
 * (implements 'cmd_generateCppCode', 'cmd_generateJsCode')
 */
var gCmdGenerateCode = 
{
  isCommandEnabled: function(aCommand) { 
    return (gXpcomViewer.getSelectedTreeItem().mIndex == -1) ? false : true;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var selected = gXpcomViewer.getSelectedTreeItem();
    var res = false;
    var template = "";
    
		// Generate JavaScript code for selected item
    if(selected.mType == "class" || selected.mType == "ifaceConstant" || 
       selected.mType == "result")
    {
      switch(selected.mType) {
        case "class":
          if(aCommand == "cmd_generateJSCode") 
            template = "Components.classes[\"" + selected.mName + "\"]"; //JavaScript
          else if(aCommand == "cmd_generatePythonCode")
            template = "components.classes[\"" + selected.mName + "\"]"; // Python
          else
            template = ""; // C++
          break;
        
        case "ifaceConstant":
          var parentIfaceIdx = gXpcomTree.view.getParentIndex(gXpcomTree.currentIndex);
          var parentIfaceName = gXpcomTree.view.getCellText(parentIfaceIdx, gXpcomTree.columns.getPrimaryColumn());
          if(aCommand == "cmd_generateJSCode")
            template = "Components.interfaces." + parentIfaceName + "." + selected.mName; //JavaScript
          else if(aCommand == "cmd_generatePythonCode")
            template = "components.interfaces." + parentIfaceName + "." + selected.mName; // Python
          else
            template = ""; // C++
          break;
        
        case "result":
          if(aCommand == "cmd_generateJSCode")
            template = "Components.results." + selected.mName; //JavaScript
          else if(aCommand == "cmd_generatePythonCode")
            template = "components.results." + selected.mName; // Python
          else
            template = selected.mName; // C++
          break;
      }
    }
    else if(selected.mType == "interface" && gCurrentTreeView == "ifaces")
    {
      if(aCommand == "cmd_generateJSCode") 
        template = "Components.interfaces." + selected.mName; //JavaScript
      else if(aCommand == "cmd_generatePythonCode")
        template = "components.interfaces." + selected.mName; // Python
      else
        template = "NS_GET_IID(" + selected.mName + ")"; // C++
    }
    else if(selected.mType == "interface" && gCurrentTreeView == "classes")
    {
      var parentClassIdx = gXpcomTree.view.getParentIndex(gXpcomTree.currentIndex);
      var parentClassName = gXpcomTree.view.getCellText(parentClassIdx, gXpcomTree.columns.getPrimaryColumn());
      if(aCommand == "cmd_generateJSCode")
        template = "var iface = Components.classes[\"" + parentClassName + "\"]." +
            "getInstance(Components.interfaces." + selected.mName + ");"; //JavaScript
      else if(aCommand == "cmd_generatePythonCode")
        template = "iface = components.classes[\"" + parentClassName+ "\"]." + 
            "createInstance()\niface = iface.queryInterface(components.interfaces." + 
            selected.mName + ")"; // Python
      else
        template = ""; // C++
    }
    else if(selected.mType == "property")
    {
      var parentIfaceIdx = gXpcomTree.view.getParentIndex(gXpcomTree.currentIndex);
      var parentIfaceName = gXpcomTree.view.getCellText(parentIfaceIdx, gXpcomTree.columns.getPrimaryColumn());
      var parentClassIdx = gXpcomTree.view.getParentIndex(parentIfaceIdx);
      var parentClassName = gXpcomTree.view.getCellText(parentClassIdx, gXpcomTree.columns.getPrimaryColumn());
      if(aCommand == "cmd_generateJSCode") {
        // JavaScript
        template = "var iface = Components.classes[\"" + parentClassName + "\"]." +
            "getInstance(Components.interfaces." + parentIfaceName + ");\n";
    		template = template + ((selected.mType == "method") 
    				? "var foo = iface." + selected.mName + "();" 
    				: "var foo = iface." + selected.mName + ";");
      } else if(aCommand == "cmd_generatePythonCode") { 
        // Python
        template = "iface = components.classes[\"" + parentClassName+ "\"]." + 
            "createInstance()\niface = iface.queryInterface(components.interfaces." + 
            selected.mName + ")\n";
    		template = template + ((selected.mType == "method") 
    				? "foo = iface." + selected.mName + "()" 
    				: "foo = iface." + selected.mName);
      } else {
        // C++
        template = "";
      }
    }
      
    res = copyTextToClipboard(template);
    if(!res) gStatusbar.update(gStrBundle.getString("doCommandError"), "error");
  }
}; // End of gCmdGenerateCode


/**
 * Show tree items with bookmark attached (apply filter)
 */
var gCmdShowWithBookmark = 
{
  isCommandEnabled: function(aCommand) {
    return (gBookmarksAllowed) ? true : false;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
	  var currentTreeView = gXpcomTreeViewBackup[gCurrentTreeView];
	  var newTreeView = [];
    
    var item = null;
    for(item in currentTreeView) 
    {
      var name = currentTreeView[item].mColumns["nameCol"].mCellText;
      
      if(gBookmarksSrv.hasItemBookmark(name)) {
        newTreeView.push(currentTreeView[item]);
      }
    }
    
	  gXpcomTreeFilter = true;
    switch(gCurrentTreeView) {
      case "classes":
        gXpcomTree.view = new TreeClassesPrototype(newTreeView);
        break;
      
      case "ifaces":
        gXpcomTree.view = new TreeIfacesPrototype(newTreeView);
        break;
      
      case "results":
        gXpcomTree.view = new TreeResultsPrototype(newTreeView);
        break;
    }
    
    gStatusbar.update(gStrBundle.getFormattedString("filterAppliedMsg",
        [newTreeView.length]), "success");
  }
}; // End of gCmdShowWithBookmark


/**
 * Add bookmark to selected tree item (if no another is attached)
 */
var gCmdAddBookmark = 
{
  isCommandEnabled: function(aCommand) { 
    // XXX Is any treeitem selected? Has no bookmark? Return true.
    return false;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    gBookmarksSrv.addBookmark();
  }
}; // End of gCmdAddBookmark


/**
 * Edit bookmark of selected tree item (if has one attached)
 */
var gCmdEditBookmark = 
{
  isCommandEnabled: function(aCommand) { 
    // XXX Is any treeitem selected? Has bookmark? Return true.
    return false;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    gBookmarksSrv.editBookmark();
  }
}; // End of gCmdEditBookmark


/**
 * Remove bookmark of selected tree item (if has one attached)
 */
var gCmdRemoveBookmark = 
{
  isCommandEnabled: function(aCommand) { 
    // XXX Is any treeitem selected? Has bookmark? Return true.
    return false;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    gBookmarksSrv.removeBookmark();
  }
}; // End of gCmdRemoveBookmark


/**
 * Toggle bottom pane
 */
var gCmdToggleBottompane = 
{
  isCommandEnabled: function(aCommand) {
    return (gBookmarksAllowed) ? true : false;
  },
  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
  doCommandParams: function(aCommand, aParams, aRefCon) {},
  doCommand: function(aCommand) 
  {
    var menuitem = document.getElementById("toggleBottompane-menuitem");
    
    if(menuitem.hasAttribute("checked")) {
      gBookmarksTree.collapsed = false;
      gBookmarksTreeSplitter.collapsed = false;
      menuitem.checked = true;
    } else {
      gBookmarksTree.collapsed = true;
      gBookmarksTreeSplitter.collapsed = true;
      menuitem.checked = false;
    }
  }
}; // End of gCmdToggleBottompane
